import { table } from "console";
import { Association } from "sequelize";

const { Sequelize, DataTypes } = require('sequelize');

export const TablesConfig = [
    {
        tableNameCn:'题目表',
        tableName:'question',
        schema:{
            qid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            title: {type:DataTypes.STRING(255)}, //题目类型：1. 霍兰德
            test_type: {type:DataTypes.TINYINT(1)}, //章节：1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
            chapter: {type:DataTypes.TINYINT(2)}, //章节
            sort: {type:DataTypes.INTEGER(255)}, //排序
            last_update_time: {type:DataTypes.DATE(0)}, //最后修改时间
            create_time: {type:DataTypes.DATE(0)}, //创建时间
            is_del: {type:DataTypes.TINYINT(1)}, //是否删除 0.正常  1.已删除
        },
        association: [
            {type:"hasMany", check:"option", foreignKey:"qid"}
        ]
    },
    {
        tableNameCn:'题目选项表',
        tableName:'option',
        schema:{
            oid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            qid: {type:DataTypes.INTEGER(11)}, //题目ID
            option_name: {type:DataTypes.STRING(255)}, //选项名称
            points: {type:DataTypes.INTEGER(11)}, //分值
            sort: {type:DataTypes.INTEGER(11)}, //排序
            last_update_time: {type:DataTypes.DATE(0)}, //最后修改时间
            create_time: {type:DataTypes.DATE(0)}, //创建时间
            is_del: {type:DataTypes.TINYINT(1)}, //是否删除 0.正常  1.已删除
        },
        association: [
            {type: "hasMany", check: "question", foreignKey: "qid"}
            // {type: "belongsTo", check: "question", foreignKey:"qid"}
        ]
    },
    {
        tableNameCn:'省市区表',
        tableName:'area',
        schema:{
            id: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            pid: {type:DataTypes.INTEGER(11),allowNull:false}, //父级ID  0表示最高节点
            name: {type:DataTypes.STRING(500)}, //名字
            visible: {type:DataTypes.TINYINT(4)}, //是否显示 1.不显示 2.显示
            displayorder: {type:DataTypes.INTEGER(11)}, //显示顺序
            level: {type:DataTypes.TINYINT(3)}, //层级别 1.省 2.市 3.区
            },
            association: [
                // {type: "belongsTo", check: "area", foreignKey:"pid"}
            ]
    },
    {
        tableNameCn:'测试信息表',
        tableName:'testinfo',
        schema:{
            infoid: {
                type:DataTypes.INTEGER, //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            test_type: {type:DataTypes.TINYINT(1)}, //题目类型：1. 霍兰德
            name: {type:DataTypes.STRING(255)}, //姓名
            card:{type:DataTypes.STRING(255)},//身份证号
            phone: {type:DataTypes.STRING(255)}, //联系电话
            email: {type:DataTypes.STRING(255)}, //电子邮箱
            area:{type:DataTypes.STRING(255)}, //所在区域
            final_score: {type:DataTypes.INTEGER}, //最终得分
            test_time: {type:DataTypes.DATE}, //测试时间
            last_update_time: {type:DataTypes.DATE,allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE,allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT,allowNull:false}, //是否删除 0.正常  1.已删除
            highest_letter: {type:DataTypes.TINYINT}, //最高分字母
            second_highest_letter: {type:DataTypes.TINYINT}, //第二高分字母
            third_highest_letter: {type:DataTypes.TINYINT}, //第三高分字母  
        },
        association: [
           // { type: "hasMany", check: "inforecord", foreignKey: "infoid" }
        ]
    },
    {
        tableNameCn:'信息记录表',
        tableName:'inforecord',
        schema:{
            irid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            infoid: {type:DataTypes.INTEGER(11),allowNull:false}, //测试信息ID
            chapter: {type:DataTypes.TINYINT(2),allowNull:false}, //章节 1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
            title_str: {type:DataTypes.STRING(255),allowNull:false}, //记录标题用逗号隔开
            option_str: {type:DataTypes.STRING(255),allowNull:false}, //记录结果用逗号隔开
            last_update_time: {type:DataTypes.DATE(0),allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE(0),allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT(1),allowNull:false}, //是否删除 0.正常  1.已删除
        },
        association: [
            //{ type: "belongsTo", check: "testinfo", foreignKey: "infoid" }
        ]
    }
            
    

    
    // {
    //     tableNameCn:'企业基础信息表',
    //     tableName:'enterprise',
    //     schema:{
    //         eId:{
    //             type:DataTypes.INTEGER, //表示属性的数据类型
    //             allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
    //             primaryKey:true, //表示主键
    //             unique:true, //表示该列的值必须唯一
    //             autoIncrement:true //设置为主键并自增
    //         },
    //         enterpriseName: {type:DataTypes.STRING(255), allowNull:false}, //企业名称
    //         uscc: {type:DataTypes.STRING(18), allowNull:false}, //统一信用代码
    //         zhuCeHao:{type:DataTypes.STRING(100)},//注册号
    //         zuZhiJiGouDaiMa: {type:DataTypes.STRING(18)}, //组织机构代码
    //         gengDuoDianHua: {type:DataTypes.STRING(255)}, //更多电话
    //         mainBusiness: {type:DataTypes.TEXT}, //主营业务
    //         logonTime: {type:DataTypes.DATE}, //注册日期
    //         mail: {type:DataTypes.STRING(255)}, //邮箱
    //         isNaturalPersonHolding: {type:DataTypes.INTEGER}, //是否自然人控股企业（1表示是，0表示否） 【枚举】
    //         industry: {type:DataTypes.STRING(255)}, //领域
    //         moreMail: {type:DataTypes.STRING(255)}, //更多邮箱
    //         // dianHua: {type:DataTypes.STRING(100)}, //电话
    //         logonAddress: {type:DataTypes.STRING(255)}, //注册地址
    //         tongXinDiZhi: {type:DataTypes.STRING(255)}, //通信地址
    //         liaison: {type:DataTypes.STRING(50)}, //联系人
    //         liaisonPhone: {type:DataTypes.STRING(255)}, //联系电话
    //         dengJiJiGuan: {type:DataTypes.STRING(255)}, //登记机关
    //         qiYeGuiMo: {type:DataTypes.STRING(50)}, //企业规模
    //         RAS: {type:DataTypes.STRING(50)}, //登记状态
    //         guanWang: {type:DataTypes.STRING(255)}, //官网地址
    //         yingYeQiXian: {type:DataTypes.STRING(50)}, //营业期限
    //         logOffMS: {type:DataTypes.DATE}, //注销时间
    //         shijiaoziben: {type:DataTypes.STRING(255)}, //实缴资本
    //         enterpriseType: {type:DataTypes.STRING(50)}, //企业机构类型
    //         jianJie: {type:DataTypes.TEXT}, //简介
    //         zhuceziben: {type:DataTypes.STRING(255)}, //注册资本
    //         naShuiRenZiZhi: {type:DataTypes.STRING(50)}, //纳税人资质
    //         operatingAddress: {type:DataTypes.STRING(255)}, //经营地址
    //         oldLogonAddress: {type:DataTypes.STRING(255)},//迁入前注册地址
    //         shuiHao:{type:DataTypes.STRING(255)},//税号
    //         shuiWuJu:{type:DataTypes.STRING(255)},//税务局
    //         jingYingFanWei:{type:DataTypes.TEXT},//经营范围
    //         //状态标识
    //         register:{type:DataTypes.INTEGER},//是否通过申请 0=否 1=是
    //         state:{type:DataTypes.INTEGER},//是否通过入孵审核 0=否 1=是
    //         //临时填充信息用的验证码
    //         randomCode:{type:DataTypes.STRING(255)}
    //     },
    //     association: [
    //         {type: "hasMany", check: "enterprise_fuhua", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_lease", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_user", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_financing", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_honor", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_manage", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_qualification", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_canbao", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_team", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_ipr", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_legal_person", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_patent", foreignKey:"eId"},
    //         {type: "hasMany", check: "enterprise_service", foreignKey:"eId"}
    //     ]
    // },

]; 